/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2010 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "stream-tube.h"
#include <TelepathyQt4/PendingOperation>

namespace Tp {

/**
 * \class IncomingDBusTube
 * \headerfile TelepathyQt4/dbus-tube.h <TelepathyQt4/IncomingDBusTube>
 *
 * \brief A class representing an incoming DBus Tube
 *
 * \c IncomingDBusTube is an high level wrapper for managing an incoming DBus Tube.
 *
 * For more details, please refer to Telepathy spec.
 */
class IncomingDBusTube : public Channel
{
    Q_OBJECT
    Q_DISABLE_COPY(IncomingDBusTube)

public:
    /**
     * Create a new IncomingDBusTube channel.
     *
     * \param connection Connection owning this channel, and specifying the
     *                   service.
     * \param objectPath The object path of this channel.
     * \param immutableProperties The immutable properties of this channel.
     * \return A IncomingDBusTubePtr object pointing to the newly created
     *         IncomingDBusTube object.
     */
    static IncomingDBusTubePtr create(const ConnectionPtr &connection,
            const QString &objectPath, const QVariantMap &immutableProperties);

public Q_SLOTS:
    /**
     * Accept a DBus tube. This function has effect only upon tubes in \c LocalPending state.
     * When this function is called, the connection manager will attempt opening the tube,
     * and will return a PendingDBusConnection to be used once the connection has been opened.
     *
     * \note Differently from Telepathy-Qt4, once the PendingDBusConnection returns (if successful) the
     *       tube is guaranteed to be already Open.
     *
     * \returns a \c PendingDBusConnection for monitoring the request and obtaining the private
     *          bus connection upon success.
     */
    PendingDBusConnection *accept();

protected:
    IncomingDBusTube(const ConnectionPtr &connection, const QString &objectPath,
            const QVariantMap &immutableProperties);
};

}
