/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2010 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "stream-tube.h"
#include <TelepathyQt4/PendingOperation>

namespace Tp {

/**
 * \class IncomingStreamTube
 * \headerfile TelepathyQt4/stream-tube.h <TelepathyQt4/IncomingStreamTube>
 *
 * \brief A class representing a Stream Tube
 *
 * \c IncomingStreamTube is an high level wrapper for managing an incoming stream tube
 */
class IncomingStreamTube : public StreamTube
{
    Q_OBJECT
    Q_DISABLE_COPY(IncomingStreamTube)

public:
    /**
     * Create a new IncomingStreamTube channel.
     *
     * \param connection Connection owning this channel, and specifying the
     *                   service.
     * \param objectPath The object path of this channel.
     * \param immutableProperties The immutable properties of this channel.
     * \return A IncomingStreamTubePtr object pointing to the newly created
     *         IncomingStreamTube object.
     */
    static IncomingStreamTubePtr create(const ConnectionPtr &connection,
            const QString &objectPath, const QVariantMap &immutableProperties);

    /**
     * Accept a stream tube. This function has effect only upon tubes in \c LocalPending state.
     * When this function is called, the connection manager will attempt opening the tube,
     * and will return a PendingIODevice to be used once the connection has been opened.
     *
     * \note Differently from Telepathy-Qt4, once the PendingIODevice returns (if successful) the
     *       tube is guaranteed to be already Open.
     *
     * \returns a \c PendingIODevice for monitoring the request and obtaining the device
     *          upon success.
     */
    PendingIODevice *acceptTube();

protected:
    IncomingStreamTube(const ConnectionPtr &connection, const QString &objectPath,
            const QVariantMap &immutableProperties);
};

}
