/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2010 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "stream-tube.h"
#include <TelepathyQt4/PendingOperation>

namespace Tp {

/**
 * \class OutgoingOutgoingStreamTube
 * \headerfile TelepathyQt4/stream-tube.h <TelepathyQt4/OutgoingStreamTube>
 *
 * \brief A class representing a Stream Tube
 *
 * \c OutgoingStreamTube is an high level wrapper for managing Telepathy interface
 * org.freedesktop.Telepathy.Channel.Type.OutgoingStreamTube.
 * It provides a transport for reliable and ordered data transfer, similar to SOCK_STREAM sockets.
 *
 * For more details, please refer to Telepathy spec.
 */
class OutgoingStreamTube : public StreamTube
{
    Q_OBJECT
    Q_DISABLE_COPY(OutgoingStreamTube)

public:
    /**
     * Create a new OutgoingStreamTube channel.
     *
     * \param connection Connection owning this channel, and specifying the
     *                   service.
     * \param objectPath The object path of this channel.
     * \param immutableProperties The immutable properties of this channel.
     * \return A OutgoingStreamTubePtr object pointing to the newly created
     *         OutgoingStreamTube object.
     */
    static OutgoingStreamTubePtr create(const ConnectionPtr &connection,
            const QString &objectPath, const QVariantMap &immutableProperties);

    /**
     * Offer a stream tube exporting the local socket specified.
     * The PendingIODevice will report the operation as finished when the tube has been successfully opened
     * and the socket is ready to be used.
     *
     * \note Differently from Telepathy-Qt4, once the PendingIODevice returns (if successful) the
     *       tube is guaranteed to be already Open.
     *
     * \returns a PendingIODevice for monitoring the request and obtaining the opened IODevice.
     */
    PendingIODevice *offerTube();

protected:
    OutgoingStreamTube(const ConnectionPtr &connection, const QString &objectPath,
            const QVariantMap &immutableProperties);
};

}
