/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2010 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _TelepathyQt4_tube_channel_creation_properties_h_HEADER_GUARD_
#define _TelepathyQt4_tube_channel_creation_properties_h_HEADER_GUARD_

#ifndef IN_TELEPATHY_QT4_HEADER
#error IN_TELEPATHY_QT4_HEADER
#endif

#include <TelepathyQt4/Constants>
#include <TelepathyQt4/Global>

#include <QDateTime>
#include <QSharedDataPointer>
#include <QString>

class QIODevice;
class QVariantMap;

namespace Tp
{

class TELEPATHY_QT4_EXPORT StreamTubeChannelCreationProperties
{
public:
    StreamTubeChannelCreationProperties(const QString &service,
                                        const QVariantMap &parameters,
                                        QIODevice *device);
    StreamTubeChannelCreationProperties(
            const StreamTubeChannelCreationProperties &other);
    ~StreamTubeChannelCreationProperties();

    StreamTubeChannelCreationProperties &operator=(
            const StreamTubeChannelCreationProperties &other);
    bool operator==(
            const StreamTubeChannelCreationProperties &other) const;
    inline bool operator!=(
            const StreamTubeChannelCreationProperties &other) const
    {
        return !(*this == other);
    }

    StreamTubeChannelCreationProperties &setService(
            const QString &service);
    StreamTubeChannelCreationProperties &setParameters(
            const QVariantMap &parameters);
    StreamTubeChannelCreationProperties &setDevice(
            QIODevice *device);

private:
    friend class Account;

    /* mandatory parameters */
    QString service() const;
    QVariantMap parameters() const;
    QIODevice *device() const;

    struct Private;
    friend struct Private;
    QSharedDataPointer<Private> mPriv;
};

class TELEPATHY_QT4_EXPORT DBusTubeChannelCreationProperties
{
public:
    DBusTubeChannelCreationProperties(const QString &serviceName);
    DBusTubeChannelCreationProperties(
            const DBusTubeChannelCreationProperties &other);
    ~DBusTubeChannelCreationProperties();

    DBusTubeChannelCreationProperties &operator=(
            const DBusTubeChannelCreationProperties &other);
    bool operator==(
            const DBusTubeChannelCreationProperties &other) const;
    inline bool operator!=(
            const DBusTubeChannelCreationProperties &other) const
    {
        return !(*this == other);
    }

    DBusTubeChannelCreationProperties &setServiceName(
            const QString &serviceName);
    DBusTubeChannelCreationProperties &setParameters(
            const QVariantMap &parameters);

private:
    friend class Account;

    QVariantMap parameters() const;

    /* mandatory parameters */
    QString service() const;

    struct Private;
    friend struct Private;
    QSharedDataPointer<Private> mPriv;
};

} // Tp

#endif
